# Tutorial do livro HeadFirst Python

### * Versão 1.0.0
      * Capítulo 2 p49
### * Versão 1.1.0
      * Capítulo 2 p60
### * Versão 1.2.0
      * Capítulo 2 p65
### * Versão 1.3.0
      * Capítulo 2 p69
